@@ -3,9 +3,9 @@ Main interface for elb service type definitions.
 
 Usage::
 
-    from mypy_boto3.elb.type_defs import AddAvailabilityZonesOutputTypeDef
+    from mypy_boto3.elb.type_defs import AccessLogTypeDef
 
-    data: AddAvailabilityZonesOutputTypeDef = {...}
+    data: AccessLogTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -18,42 +18,42 @@ else:
 
 
 __all__ = (
-    "AddAvailabilityZonesOutputTypeDef",
-    "ApplySecurityGroupsToLoadBalancerOutputTypeDef",
-    "AttachLoadBalancerToSubnetsOutputTypeDef",
-    "HealthCheckTypeDef",
-    "ConfigureHealthCheckOutputTypeDef",
-    "CreateAccessPointOutputTypeDef",
-    "InstanceTypeDef",
-    "DeregisterEndPointsOutputTypeDef",
-    "BackendServerDescriptionTypeDef",
-    "ListenerTypeDef",
-    "ListenerDescriptionTypeDef",
-    "AppCookieStickinessPolicyTypeDef",
-    "LBCookieStickinessPolicyTypeDef",
-    "PoliciesTypeDef",
-    "SourceSecurityGroupTypeDef",
-    "LoadBalancerDescriptionTypeDef",
-    "DescribeAccessPointsOutputTypeDef",
-    "LimitTypeDef",
-    "DescribeAccountLimitsOutputTypeDef",
-    "InstanceStateTypeDef",
-    "DescribeEndPointStateOutputTypeDef",
     "AccessLogTypeDef",
     "AdditionalAttributeTypeDef",
+    "AppCookieStickinessPolicyTypeDef",
+    "BackendServerDescriptionTypeDef",
     "ConnectionDrainingTypeDef",
     "ConnectionSettingsTypeDef",
     "CrossZoneLoadBalancingTypeDef",
+    "HealthCheckTypeDef",
+    "InstanceStateTypeDef",
+    "InstanceTypeDef",
+    "LBCookieStickinessPolicyTypeDef",
+    "LimitTypeDef",
+    "ListenerDescriptionTypeDef",
+    "ListenerTypeDef",
     "LoadBalancerAttributesTypeDef",
-    "DescribeLoadBalancerAttributesOutputTypeDef",
+    "LoadBalancerDescriptionTypeDef",
+    "PoliciesTypeDef",
     "PolicyAttributeDescriptionTypeDef",
-    "PolicyDescriptionTypeDef",
-    "DescribeLoadBalancerPoliciesOutputTypeDef",
     "PolicyAttributeTypeDescriptionTypeDef",
+    "PolicyDescriptionTypeDef",
     "PolicyTypeDescriptionTypeDef",
-    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
-    "TagTypeDef",
+    "SourceSecurityGroupTypeDef",
     "TagDescriptionTypeDef",
+    "TagTypeDef",
+    "AddAvailabilityZonesOutputTypeDef",
+    "ApplySecurityGroupsToLoadBalancerOutputTypeDef",
+    "AttachLoadBalancerToSubnetsOutputTypeDef",
+    "ConfigureHealthCheckOutputTypeDef",
+    "CreateAccessPointOutputTypeDef",
+    "DeregisterEndPointsOutputTypeDef",
+    "DescribeAccessPointsOutputTypeDef",
+    "DescribeAccountLimitsOutputTypeDef",
+    "DescribeEndPointStateOutputTypeDef",
+    "DescribeLoadBalancerAttributesOutputTypeDef",
+    "DescribeLoadBalancerPoliciesOutputTypeDef",
+    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
     "DescribeTagsOutputTypeDef",
     "DetachLoadBalancerFromSubnetsOutputTypeDef",
     "ModifyLoadBalancerAttributesOutputTypeDef",
@@ -65,138 +65,6 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
-AddAvailabilityZonesOutputTypeDef = TypedDict(
-    "AddAvailabilityZonesOutputTypeDef", {"AvailabilityZones": List[str]}, total=False
-)
-
-ApplySecurityGroupsToLoadBalancerOutputTypeDef = TypedDict(
-    "ApplySecurityGroupsToLoadBalancerOutputTypeDef", {"SecurityGroups": List[str]}, total=False
-)
-
-AttachLoadBalancerToSubnetsOutputTypeDef = TypedDict(
-    "AttachLoadBalancerToSubnetsOutputTypeDef", {"Subnets": List[str]}, total=False
-)
-
-HealthCheckTypeDef = TypedDict(
-    "HealthCheckTypeDef",
-    {
-        "Target": str,
-        "Interval": int,
-        "Timeout": int,
-        "UnhealthyThreshold": int,
-        "HealthyThreshold": int,
-    },
-)
-
-ConfigureHealthCheckOutputTypeDef = TypedDict(
-    "ConfigureHealthCheckOutputTypeDef", {"HealthCheck": HealthCheckTypeDef}, total=False
-)
-
-CreateAccessPointOutputTypeDef = TypedDict(
-    "CreateAccessPointOutputTypeDef", {"DNSName": str}, total=False
-)
-
-InstanceTypeDef = TypedDict("InstanceTypeDef", {"InstanceId": str}, total=False)
-
-DeregisterEndPointsOutputTypeDef = TypedDict(
-    "DeregisterEndPointsOutputTypeDef", {"Instances": List[InstanceTypeDef]}, total=False
-)
-
-BackendServerDescriptionTypeDef = TypedDict(
-    "BackendServerDescriptionTypeDef", {"InstancePort": int, "PolicyNames": List[str]}, total=False
-)
-
-_RequiredListenerTypeDef = TypedDict(
-    "_RequiredListenerTypeDef", {"Protocol": str, "LoadBalancerPort": int, "InstancePort": int}
-)
-_OptionalListenerTypeDef = TypedDict(
-    "_OptionalListenerTypeDef", {"InstanceProtocol": str, "SSLCertificateId": str}, total=False
-)
-
-
-class ListenerTypeDef(_RequiredListenerTypeDef, _OptionalListenerTypeDef):
-    pass
-
-
-ListenerDescriptionTypeDef = TypedDict(
-    "ListenerDescriptionTypeDef",
-    {"Listener": ListenerTypeDef, "PolicyNames": List[str]},
-    total=False,
-)
-
-AppCookieStickinessPolicyTypeDef = TypedDict(
-    "AppCookieStickinessPolicyTypeDef", {"PolicyName": str, "CookieName": str}, total=False
-)
-
-LBCookieStickinessPolicyTypeDef = TypedDict(
-    "LBCookieStickinessPolicyTypeDef",
-    {"PolicyName": str, "CookieExpirationPeriod": int},
-    total=False,
-)
-
-PoliciesTypeDef = TypedDict(
-    "PoliciesTypeDef",
-    {
-        "AppCookieStickinessPolicies": List[AppCookieStickinessPolicyTypeDef],
-        "LBCookieStickinessPolicies": List[LBCookieStickinessPolicyTypeDef],
-        "OtherPolicies": List[str],
-    },
-    total=False,
-)
-
-SourceSecurityGroupTypeDef = TypedDict(
-    "SourceSecurityGroupTypeDef", {"OwnerAlias": str, "GroupName": str}, total=False
-)
-
-LoadBalancerDescriptionTypeDef = TypedDict(
-    "LoadBalancerDescriptionTypeDef",
-    {
-        "LoadBalancerName": str,
-        "DNSName": str,
-        "CanonicalHostedZoneName": str,
-        "CanonicalHostedZoneNameID": str,
-        "ListenerDescriptions": List[ListenerDescriptionTypeDef],
-        "Policies": PoliciesTypeDef,
-        "BackendServerDescriptions": List[BackendServerDescriptionTypeDef],
-        "AvailabilityZones": List[str],
-        "Subnets": List[str],
-        "VPCId": str,
-        "Instances": List[InstanceTypeDef],
-        "HealthCheck": HealthCheckTypeDef,
-        "SourceSecurityGroup": SourceSecurityGroupTypeDef,
-        "SecurityGroups": List[str],
-        "CreatedTime": datetime,
-        "Scheme": str,
-    },
-    total=False,
-)
-
-DescribeAccessPointsOutputTypeDef = TypedDict(
-    "DescribeAccessPointsOutputTypeDef",
-    {"LoadBalancerDescriptions": List[LoadBalancerDescriptionTypeDef], "NextMarker": str},
-    total=False,
-)
-
-LimitTypeDef = TypedDict("LimitTypeDef", {"Name": str, "Max": str}, total=False)
-
-DescribeAccountLimitsOutputTypeDef = TypedDict(
-    "DescribeAccountLimitsOutputTypeDef",
-    {"Limits": List[LimitTypeDef], "NextMarker": str},
-    total=False,
-)
-
-InstanceStateTypeDef = TypedDict(
-    "InstanceStateTypeDef",
-    {"InstanceId": str, "State": str, "ReasonCode": str, "Description": str},
-    total=False,
-)
-
-DescribeEndPointStateOutputTypeDef = TypedDict(
-    "DescribeEndPointStateOutputTypeDef",
-    {"InstanceStates": List[InstanceStateTypeDef]},
-    total=False,
-)
-
 _RequiredAccessLogTypeDef = TypedDict("_RequiredAccessLogTypeDef", {"Enabled": bool})
 _OptionalAccessLogTypeDef = TypedDict(
     "_OptionalAccessLogTypeDef",
@@ -213,6 +81,14 @@ AdditionalAttributeTypeDef = TypedDict(
     "AdditionalAttributeTypeDef", {"Key": str, "Value": str}, total=False
 )
 
+AppCookieStickinessPolicyTypeDef = TypedDict(
+    "AppCookieStickinessPolicyTypeDef", {"PolicyName": str, "CookieName": str}, total=False
+)
+
+BackendServerDescriptionTypeDef = TypedDict(
+    "BackendServerDescriptionTypeDef", {"InstancePort": int, "PolicyNames": List[str]}, total=False
+)
+
 _RequiredConnectionDrainingTypeDef = TypedDict(
     "_RequiredConnectionDrainingTypeDef", {"Enabled": bool}
 )
@@ -231,21 +107,93 @@ ConnectionSettingsTypeDef = TypedDict("ConnectionSettingsTypeDef", {"IdleTimeout
 
 CrossZoneLoadBalancingTypeDef = TypedDict("CrossZoneLoadBalancingTypeDef", {"Enabled": bool})
 
+HealthCheckTypeDef = TypedDict(
+    "HealthCheckTypeDef",
+    {
+        "Target": str,
+        "Interval": int,
+        "Timeout": int,
+        "UnhealthyThreshold": int,
+        "HealthyThreshold": int,
+    },
+)
+
+InstanceStateTypeDef = TypedDict(
+    "InstanceStateTypeDef",
+    {"InstanceId": str, "State": str, "ReasonCode": str, "Description": str},
+    total=False,
+)
+
+InstanceTypeDef = TypedDict("InstanceTypeDef", {"InstanceId": str}, total=False)
+
+LBCookieStickinessPolicyTypeDef = TypedDict(
+    "LBCookieStickinessPolicyTypeDef",
+    {"PolicyName": str, "CookieExpirationPeriod": int},
+    total=False,
+)
+
+LimitTypeDef = TypedDict("LimitTypeDef", {"Name": str, "Max": str}, total=False)
+
+ListenerDescriptionTypeDef = TypedDict(
+    "ListenerDescriptionTypeDef",
+    {"Listener": "ListenerTypeDef", "PolicyNames": List[str]},
+    total=False,
+)
+
+_RequiredListenerTypeDef = TypedDict(
+    "_RequiredListenerTypeDef", {"Protocol": str, "LoadBalancerPort": int, "InstancePort": int}
+)
+_OptionalListenerTypeDef = TypedDict(
+    "_OptionalListenerTypeDef", {"InstanceProtocol": str, "SSLCertificateId": str}, total=False
+)
+
+
+class ListenerTypeDef(_RequiredListenerTypeDef, _OptionalListenerTypeDef):
+    pass
+
+
 LoadBalancerAttributesTypeDef = TypedDict(
     "LoadBalancerAttributesTypeDef",
     {
-        "CrossZoneLoadBalancing": CrossZoneLoadBalancingTypeDef,
-        "AccessLog": AccessLogTypeDef,
-        "ConnectionDraining": ConnectionDrainingTypeDef,
-        "ConnectionSettings": ConnectionSettingsTypeDef,
-        "AdditionalAttributes": List[AdditionalAttributeTypeDef],
+        "CrossZoneLoadBalancing": "CrossZoneLoadBalancingTypeDef",
+        "AccessLog": "AccessLogTypeDef",
+        "ConnectionDraining": "ConnectionDrainingTypeDef",
+        "ConnectionSettings": "ConnectionSettingsTypeDef",
+        "AdditionalAttributes": List["AdditionalAttributeTypeDef"],
     },
     total=False,
 )
 
-DescribeLoadBalancerAttributesOutputTypeDef = TypedDict(
-    "DescribeLoadBalancerAttributesOutputTypeDef",
-    {"LoadBalancerAttributes": LoadBalancerAttributesTypeDef},
+LoadBalancerDescriptionTypeDef = TypedDict(
+    "LoadBalancerDescriptionTypeDef",
+    {
+        "LoadBalancerName": str,
+        "DNSName": str,
+        "CanonicalHostedZoneName": str,
+        "CanonicalHostedZoneNameID": str,
+        "ListenerDescriptions": List["ListenerDescriptionTypeDef"],
+        "Policies": "PoliciesTypeDef",
+        "BackendServerDescriptions": List["BackendServerDescriptionTypeDef"],
+        "AvailabilityZones": List[str],
+        "Subnets": List[str],
+        "VPCId": str,
+        "Instances": List["InstanceTypeDef"],
+        "HealthCheck": "HealthCheckTypeDef",
+        "SourceSecurityGroup": "SourceSecurityGroupTypeDef",
+        "SecurityGroups": List[str],
+        "CreatedTime": datetime,
+        "Scheme": str,
+    },
+    total=False,
+)
+
+PoliciesTypeDef = TypedDict(
+    "PoliciesTypeDef",
+    {
+        "AppCookieStickinessPolicies": List["AppCookieStickinessPolicyTypeDef"],
+        "LBCookieStickinessPolicies": List["LBCookieStickinessPolicyTypeDef"],
+        "OtherPolicies": List[str],
+    },
     total=False,
 )
 
@@ -253,22 +201,6 @@ PolicyAttributeDescriptionTypeDef = TypedDict(
     "PolicyAttributeDescriptionTypeDef", {"AttributeName": str, "AttributeValue": str}, total=False
 )
 
-PolicyDescriptionTypeDef = TypedDict(
-    "PolicyDescriptionTypeDef",
-    {
-        "PolicyName": str,
-        "PolicyTypeName": str,
-        "PolicyAttributeDescriptions": List[PolicyAttributeDescriptionTypeDef],
-    },
-    total=False,
-)
-
-DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
-    "DescribeLoadBalancerPoliciesOutputTypeDef",
-    {"PolicyDescriptions": List[PolicyDescriptionTypeDef]},
-    total=False,
-)
-
 PolicyAttributeTypeDescriptionTypeDef = TypedDict(
     "PolicyAttributeTypeDescriptionTypeDef",
     {
@@ -281,20 +213,32 @@ PolicyAttributeTypeDescriptionTypeDef = TypedDict(
     total=False,
 )
 
+PolicyDescriptionTypeDef = TypedDict(
+    "PolicyDescriptionTypeDef",
+    {
+        "PolicyName": str,
+        "PolicyTypeName": str,
+        "PolicyAttributeDescriptions": List["PolicyAttributeDescriptionTypeDef"],
+    },
+    total=False,
+)
+
 PolicyTypeDescriptionTypeDef = TypedDict(
     "PolicyTypeDescriptionTypeDef",
     {
         "PolicyTypeName": str,
         "Description": str,
-        "PolicyAttributeTypeDescriptions": List[PolicyAttributeTypeDescriptionTypeDef],
+        "PolicyAttributeTypeDescriptions": List["PolicyAttributeTypeDescriptionTypeDef"],
     },
     total=False,
 )
 
-DescribeLoadBalancerPolicyTypesOutputTypeDef = TypedDict(
-    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
-    {"PolicyTypeDescriptions": List[PolicyTypeDescriptionTypeDef]},
-    total=False,
+SourceSecurityGroupTypeDef = TypedDict(
+    "SourceSecurityGroupTypeDef", {"OwnerAlias": str, "GroupName": str}, total=False
+)
+
+TagDescriptionTypeDef = TypedDict(
+    "TagDescriptionTypeDef", {"LoadBalancerName": str, "Tags": List["TagTypeDef"]}, total=False
 )
 
 _RequiredTagTypeDef = TypedDict("_RequiredTagTypeDef", {"Key": str})
@@ -305,12 +249,68 @@ class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
     pass
 
 
-TagDescriptionTypeDef = TypedDict(
-    "TagDescriptionTypeDef", {"LoadBalancerName": str, "Tags": List[TagTypeDef]}, total=False
+AddAvailabilityZonesOutputTypeDef = TypedDict(
+    "AddAvailabilityZonesOutputTypeDef", {"AvailabilityZones": List[str]}, total=False
+)
+
+ApplySecurityGroupsToLoadBalancerOutputTypeDef = TypedDict(
+    "ApplySecurityGroupsToLoadBalancerOutputTypeDef", {"SecurityGroups": List[str]}, total=False
+)
+
+AttachLoadBalancerToSubnetsOutputTypeDef = TypedDict(
+    "AttachLoadBalancerToSubnetsOutputTypeDef", {"Subnets": List[str]}, total=False
+)
+
+ConfigureHealthCheckOutputTypeDef = TypedDict(
+    "ConfigureHealthCheckOutputTypeDef", {"HealthCheck": "HealthCheckTypeDef"}, total=False
+)
+
+CreateAccessPointOutputTypeDef = TypedDict(
+    "CreateAccessPointOutputTypeDef", {"DNSName": str}, total=False
+)
+
+DeregisterEndPointsOutputTypeDef = TypedDict(
+    "DeregisterEndPointsOutputTypeDef", {"Instances": List["InstanceTypeDef"]}, total=False
+)
+
+DescribeAccessPointsOutputTypeDef = TypedDict(
+    "DescribeAccessPointsOutputTypeDef",
+    {"LoadBalancerDescriptions": List["LoadBalancerDescriptionTypeDef"], "NextMarker": str},
+    total=False,
+)
+
+DescribeAccountLimitsOutputTypeDef = TypedDict(
+    "DescribeAccountLimitsOutputTypeDef",
+    {"Limits": List["LimitTypeDef"], "NextMarker": str},
+    total=False,
+)
+
+DescribeEndPointStateOutputTypeDef = TypedDict(
+    "DescribeEndPointStateOutputTypeDef",
+    {"InstanceStates": List["InstanceStateTypeDef"]},
+    total=False,
+)
+
+DescribeLoadBalancerAttributesOutputTypeDef = TypedDict(
+    "DescribeLoadBalancerAttributesOutputTypeDef",
+    {"LoadBalancerAttributes": "LoadBalancerAttributesTypeDef"},
+    total=False,
+)
+
+DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
+    "DescribeLoadBalancerPoliciesOutputTypeDef",
+    {"PolicyDescriptions": List["PolicyDescriptionTypeDef"]},
+    total=False,
+)
+
+DescribeLoadBalancerPolicyTypesOutputTypeDef = TypedDict(
+    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
+    {"PolicyTypeDescriptions": List["PolicyTypeDescriptionTypeDef"]},
+    total=False,
 )
 
 DescribeTagsOutputTypeDef = TypedDict(
-    "DescribeTagsOutputTypeDef", {"TagDescriptions": List[TagDescriptionTypeDef]}, total=False
+    "DescribeTagsOutputTypeDef", {"TagDescriptions": List["TagDescriptionTypeDef"]}, total=False
 )
 
 DetachLoadBalancerFromSubnetsOutputTypeDef = TypedDict(
@@ -319,7 +319,7 @@ DetachLoadBalancerFromSubnetsOutputTypeDef = TypedDict(
 
 ModifyLoadBalancerAttributesOutputTypeDef = TypedDict(
     "ModifyLoadBalancerAttributesOutputTypeDef",
-    {"LoadBalancerName": str, "LoadBalancerAttributes": LoadBalancerAttributesTypeDef},
+    {"LoadBalancerName": str, "LoadBalancerAttributes": "LoadBalancerAttributesTypeDef"},
     total=False,
 )
 
@@ -332,7 +332,7 @@ PolicyAttributeTypeDef = TypedDict(
 )
 
 RegisterEndPointsOutputTypeDef = TypedDict(
-    "RegisterEndPointsOutputTypeDef", {"Instances": List[InstanceTypeDef]}, total=False
+    "RegisterEndPointsOutputTypeDef", {"Instances": List["InstanceTypeDef"]}, total=False
 )
 
 RemoveAvailabilityZonesOutputTypeDef = TypedDict(
