@@ -27,47 +27,47 @@ __all__ = ("AnyInstanceInServiceWaiter", "InstanceDeregisteredWaiter", "Instance
 
 class AnyInstanceInServiceWaiter(Boto3Waiter):
     """
-    [Waiter.AnyInstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
+    [Waiter.AnyInstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
     """
 
     def wait(
         self,
         LoadBalancerName: str,
-        Instances: List[InstanceTypeDef] = None,
+        Instances: List["InstanceTypeDef"] = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [AnyInstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
+        [AnyInstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
         """
 
 
 class InstanceDeregisteredWaiter(Boto3Waiter):
     """
-    [Waiter.InstanceDeregistered documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
+    [Waiter.InstanceDeregistered documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
     """
 
     def wait(
         self,
         LoadBalancerName: str,
-        Instances: List[InstanceTypeDef] = None,
+        Instances: List["InstanceTypeDef"] = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [InstanceDeregistered.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
+        [InstanceDeregistered.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
         """
 
 
 class InstanceInServiceWaiter(Boto3Waiter):
     """
-    [Waiter.InstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
+    [Waiter.InstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
     """
 
     def wait(
         self,
         LoadBalancerName: str,
-        Instances: List[InstanceTypeDef] = None,
+        Instances: List["InstanceTypeDef"] = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [InstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.23/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
+        [InstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
         """
